@@ -59,7 +59,7 @@ def object_hook(obj: dict, custom_data_decoder: Callable = None) -> dict:
         if key == Message.kind:
             val = obj[key]
         elif key == Message.timestamp:
-            val = from_timestamp(obj[key])
+            val = int(obj[key])
         elif key == Message.data:
             if isinstance(obj[key], str):
                 if custom_data_decoder is None:
